Crate babel47

Crate babel47 

This crate helps with handling translatable strings using BCP 47 language tags.

The LangString type collects strings for different language tags, and allows retrieving by either a concrete language lor a language range.

RDF support through Taganak

The taganak feature enables support for loading a LangString from an RDF graph using the Taganak SDK.

Structs

LangString
A single translatable string